@@ -161,6 +161,10 @@ static void change_short_options_to_long(std::string& argument)
         argument = "--format=JSTREE";
     if (argument=="-fh")
         argument = "--format=HTML";
+    if (argument=="-fc")
+        argument = "--format=CSV";
+    if (argument=="-fs")
+        argument = "--format=SIMPLE";
 
     // Compression short options
     if (argument=="-cz")
@@ -232,6 +236,7 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--watchfolder-user",                            WatchFolderUser)
     OPTION("--watchfolder",                                 WatchFolder)
     OPTION("--user",                                        User)
+    OPTION("--list",                                        List)
     //Default
     OPTION("--",                                            Default)
     else
@@ -666,6 +671,16 @@ CL_OPTION(User)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(List)
+{
+    //Form : --list
+    (void)argument;
+    cli->set_list_mode();
+
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(Default)
 {
