@@ -413,9 +413,14 @@ long Core::checker_analyze(int user, const std::string& file, bool& registered,
     {
         if (force_analyze)
         {
+            std::string file_last_modification = get_last_modification_file(file);
+            std::vector<long> generated_id;
             db_mutex.Enter();
-            get_db()->reset_file(user, id, err);
+            get_db()->remove_report(user, id, err);
+            id = get_db()->update_file(user, id, file_last_modification, options_str, err, generated_id);
             db_mutex.Leave();
+            if (id < 0)
+                return -1;
         }
         registered = true;
     }
@@ -472,6 +477,14 @@ long Core::checker_analyze(int user, const std::string& filename, long src_id, s
     return id;
 }
 
+//--------------------------------------------------------------------------
+int Core::checker_list_mediainfo_outputs(std::string& output, std::string& err)
+{
+    output = Ztring(MI->Option(L"Info_OutputFormats_JSON")).To_UTF8();
+
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int Core::file_add_generated_file(int user, long src_id, long generated_id, std::string& err)
 {
@@ -909,6 +922,43 @@ int Core::register_mediaconch_to_database(int user, long file, const std::string
     return ret;
 }
 
+//---------------------------------------------------------------------------
+
+int Core::transform_mixml_report(const std::string& mi_xml, const std::string& mi_inform,
+                                 const std::vector<std::pair<std::string,std::string> >& options,
+                                 std::string& report, std::string& err)
+{
+    MediaInfoNameSpace::MediaInfo* tmpMI=new MediaInfoNameSpace::MediaInfo;
+
+    tmpMI->Option(__T("Details"), __T("0"));
+    tmpMI->Option(__T("Inform"), Ztring().From_UTF8(mi_inform));
+
+
+    for (size_t i = 0; i < options.size(); ++i)
+    {
+        if (!options[i].first.empty() && !options[i].second.empty())
+            tmpMI->Option(Ztring().From_UTF8(options[i].first),  Ztring().From_UTF8(options[i].second));
+    }
+
+    size_t BufferSize = strlen(mi_xml.data());
+
+    if (BufferSize == 0)
+    {
+        err = "Original report is empty.";
+        return -1;
+    }
+
+    tmpMI->Open_Buffer_Init(BufferSize);
+    tmpMI->Open_Buffer_Continue((ZenLib::int8u*)mi_xml.data(), BufferSize);
+    tmpMI->Open_Buffer_Finalize();
+
+    report = Ztring(tmpMI->Inform()).To_UTF8();
+
+    delete tmpMI;
+
+    return 0;
+}
+
 //---------------------------------------------------------------------------
 int Core::get_report_saved(int user, const std::vector<long>& files,
                            MediaConchLib::report reportKind, MediaConchLib::format f,
