@@ -42,10 +42,16 @@ private:
 
     int                       create_configuration_file(const std::string& report_dir, std::string& file);
     int                       delete_configuration_file(const std::string& file);
+    int                       read_summary_report_for_new_report_file(const std::string& summary, std::string& file, std::string& error);
+    static void               manage_xml_error(void *userData, const char* msg, ...);
 
     std::string               bin;
     std::vector<std::string>  params;
     std::vector<std::string>  isos;
+
+    std::string               xml_error;
+
+    static const char        *conf_version;
 };
 
 }
