@@ -33,6 +33,7 @@ public:
 
     std::string  format_from_trace_XML(const std::string& xml);
     std::string  format_from_inform_XML(const std::string& xml);
+    std::string  format_from_inform_Text(const std::string& text);
 
     static int   policies_to_js_tree(std::vector<MediaConchLib::Policy_Policy*> vec, std::string& jstree, std::string& error);
     static int   policy_to_js_tree(MediaConchLib::Policy_Policy* policy, std::string& json, std::string& error);
@@ -51,6 +52,9 @@ private:
     void         find_trace_block_node(xmlNodePtr node, bool& sep, std::string& json);
     void         find_trace_data_node(xmlNodePtr node, bool& sep, std::string& json);
     bool         has_block_data(xmlNodePtr child);
+    void         find_inform_media_text(std::istringstream& stream, bool& sep, std::string& json);
+    void         find_inform_block_text(std::istringstream& stream, bool& sep, std::string& json);
+    void         find_inform_track_text(std::istringstream& stream, bool& sep, std::string& json);
     void         find_inform_data_node(xmlNodePtr node, bool& sep, std::string& json);
     void         find_inform_media_node(xmlNodePtr node, bool& sep, std::string& json);
     void         find_inform_track_type(xmlNodePtr node, bool& sep, std::string& json);
@@ -58,6 +62,7 @@ private:
     void         interpret_trace_data_in_block(xmlNodePtr block, std::string& json);
     void         interpret_trace_data_in_data(xmlNodePtr data, std::string& json);
 
+    void trim_string(std::string &str);
     std::string decimal_to_hexa(std::string val);
     void interpret_offset(std::string& offset, bool coma, std::string& json);
     void interpret_value(std::string& value, bool coma, std::string& json);
