@@ -114,6 +114,11 @@ public:
     struct Checker_StatusRes
     {
         Checker_StatusRes() : id(-1), finished(false), has_error(false), percent(NULL), tool(NULL), source_id(-1) {}
+        ~Checker_StatusRes()
+        {
+            delete percent;
+            delete tool;
+        }
 
         long               id;
         bool               finished;
@@ -271,7 +276,10 @@ public:
 
     //Options
     int  test_mil_option(const std::string& key, std::string& value, std::string& report);
+
+    // MediaInfo
     bool mil_has_curl_enabled();
+    int mil_get_output_list(std::string& output_list, std::string& error);
 
     // MediaConch
     int  mediaconch_get_plugins(std::vector<std::string>& plugins, std::string& error);
