@@ -53,18 +53,27 @@ public:
 
     int  add_element_to_queue(int user, const std::string& filename, long file_id,
                               const std::vector<std::pair<std::string,std::string> >& options,
-                              const std::vector<std::string>& plugins, bool mil_analyze);
+                              const std::vector<std::string>& plugins, bool mil_analyze,
+                              const std::string& alias="");
     void work_finished(QueueElement* el, MediaInfoNameSpace::MediaInfo* MI);
     bool is_finished();
+
     long element_exists(int user, const std::string& filename,
                         const std::string& options, std::string& err);
     bool element_is_finished(int user, long file_id, double& percent_done);
-    void set_max_threads(size_t nb) { max_threads = nb; }
     int  get_elements(int user, std::vector<std::string>& vec, std::string& err);
     int  get_elements(int user, std::vector<long>& vec, std::string& err);
+    int  stop_elements(int user, const std::vector<long>& vec, std::string& err);
+
     int  another_work_to_do(QueueElement* el, MediaInfoNameSpace::MediaInfo* MI);
     int  execute_pre_hook_plugins(QueueElement *el, std::string& err);
+    int  attachments_to_add(QueueElement *el);
+
     void write_log_timestamp(int level, std::string log);
+    void log_cb(struct MediaInfo_Event_Log_0 *Event);
+
+    void set_default_max_threads(size_t nb) {} // { if (max_threads_modified) return; max_threads = nb; } //TODO: check issues with the GUI when there are tons of files
+    void set_max_threads(size_t nb) { max_threads_modified = true; max_threads = nb; }
 
 private:
     Scheduler(const Scheduler&);
@@ -74,6 +83,7 @@ private:
     Queue                                  *queue;
     int                                     threads_launch;
     size_t                                  max_threads;
+    bool                                    max_threads_modified;
     std::map<QueueElement*, QueueElement*>  working;
     CriticalSection                         CS;
 
