@@ -107,6 +107,8 @@ namespace MediaConch
                                              RESTAPI::Checker_Report_Res& res, void *arg);
         static int on_checker_clear_command(const RESTAPI::Checker_Clear_Req* req,
                                             RESTAPI::Checker_Clear_Res& res, void *arg);
+        static int on_checker_stop_command(const RESTAPI::Checker_Stop_Req* req,
+                                           RESTAPI::Checker_Stop_Res& res, void *arg);
         static int on_checker_list_command(const RESTAPI::Checker_List_Req* req,
                                            RESTAPI::Checker_List_Res& res, void *arg);
         static int on_checker_validate_command(const RESTAPI::Checker_Validate_Req* req,
@@ -117,6 +119,8 @@ namespace MediaConch
                                                        RESTAPI::Checker_Id_From_Filename_Res& res, void *arg);
         static int on_checker_file_information_command(const RESTAPI::Checker_File_Information_Req* req,
                                                        RESTAPI::Checker_File_Information_Res& res, void *arg);
+        static int on_checker_list_mediainfo_outputs_command(const RESTAPI::Checker_List_MediaInfo_Outputs_Req* req,
+                                                             RESTAPI::Checker_List_MediaInfo_Outputs_Res& res, void *arg);
         static int on_default_values_for_type_command(const RESTAPI::Default_Values_For_Type_Req* req,
                                                       RESTAPI::Default_Values_For_Type_Res& res, void *arg);
 
