@@ -11,6 +11,8 @@
 
 namespace MediaConch {
 
+class MainWindow;
+
 class WebView : public QWebEngineView
 {
     Q_OBJECT
@@ -20,7 +22,10 @@ public:
     virtual ~WebView();
 
 protected:
-    void dropEvent(QDropEvent *event);
+    virtual void dropEvent(QDropEvent *event);
+    virtual void dragEnterEvent(QDragEnterEvent *event);
+
+    MainWindow *mainwindow;
 };
 
 }
