@@ -8,7 +8,6 @@
 
 #if defined(WEB_MACHINE_KIT)
 
-#include <QWebPage>
 #include <QWebFrame>
 #include <QWebElement>
 #include <QWebElementCollection>
@@ -79,6 +78,8 @@ namespace MediaConch
             return choose_file_settings();
         else if (select_file_name.startsWith("xslPolicyImport"))
             return choose_file_import_policy();
+        else if (select_file_name.startsWith("xslPolicyCreateFromFile"))
+            return choose_file_policy_from_file();
 
         QString value_input;
         std::string suggested_str;
@@ -154,6 +155,7 @@ namespace MediaConch
     {
         mainFrame()->evaluateJavaScript(js);
     }
+
 }
 
 #endif
