@@ -10,22 +10,18 @@
 #include <QFileInfo>
 #include <QString>
 #include <QStringList>
+#include "commonwebwindow.h"
 
 namespace MediaConch {
 
-class MainWindow;
-class WebView;
-class ProgressBar;
-
-class DisplayWindow : public QObject
+class DisplayWindow : public CommonWebWindow
 {
-    Q_OBJECT
-
 public:
     explicit DisplayWindow(MainWindow* m);
     ~DisplayWindow();
 
     void display_display();
+    void create_web_view_finished();
 
     int  add_new_file(const QString& name, const QString& filename);
     int  add_new_files(const QStringList& files);
@@ -33,13 +29,6 @@ public:
     void delete_file(const QString& name);
 
 private:
-    // Visual elements
-    MainWindow   *mainwindow;
-    WebView      *web_view;
-    ProgressBar  *progress_bar;
-    bool          is_finished;
-
-    void clear_display();
     void create_html(QString& html);
 
     void create_html_display(QString& display);
@@ -51,9 +40,6 @@ private:
     void remove_result_in_template(QString& base);
 
     void fill_table();
-
-private Q_SLOTS:
-    void create_web_view_finished(bool ok);
 };
 
 }
