@@ -9,6 +9,7 @@
 
 #include <QFileInfo>
 #include <QString>
+#include "commonwebwindow.h"
 
 class QVBoxLayout;
 class QLabel;
@@ -19,14 +20,8 @@ class QFrame;
 
 namespace MediaConch {
 
-class MainWindow;
-class WebView;
-class ProgressBar;
-
-class PoliciesWindow : public QObject
+class PoliciesWindow : public CommonWebWindow
 {
-    Q_OBJECT
-
 public:
     explicit PoliciesWindow(MainWindow *parent = 0);
     ~PoliciesWindow();
@@ -38,14 +33,6 @@ public:
     int                         add_new_policies(const QStringList& files);
 
 private:
-    MainWindow   *mainwindow;
-    WebView      *web_view;
-    ProgressBar  *progress_bar;
-
-//***************************************************************************
-// VISUAL
-//***************************************************************************
-    void clear_visual_elements();
 
 //***************************************************************************
 // WEB
@@ -56,16 +43,7 @@ private:
     void change_checker_in_template(const QString& policy, QString& html);
     void create_html_base(const QString& policy, QString& base);
     void create_html_policy(QString& policy);
-    void create_html();
-
-//***************************************************************************
-// SLOTS
-//***************************************************************************
-public Q_SLOTS:
-    void use_javascript(const QString& script);
-
-private Q_SLOTS:
-    void create_web_view_finished(bool ok);
+    void create_html(QString &html);
 };
 
 }
