@@ -146,7 +146,7 @@ void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered*>& f
 //---------------------------------------------------------------------------
 int WorkerFiles::add_file_to_list(const std::string& file, const std::string& path,
                                   int policy, int display, int verbosity, bool fixer,
-                                  bool force, bool create_policy, std::string& err)
+                                  bool force, bool create_policy, const std::vector<std::string>& options, std::string& err)
 {
     std::string full_file(path);
 #ifdef WINDOWS
@@ -161,13 +161,29 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     bool exists = false;
     FileRegistered *fr = NULL;
     working_files_mutex.lock();
-    if (working_files.find(full_file) != working_files.end() && working_files[full_file])
+    std::map<std::string, FileRegistered*>::iterator it = working_files.find(full_file);
+    if (it != working_files.end() && it->second)
     {
         exists = true;
+        bool same_options = true;
+        for (size_t i = 0; i < it->second->options.size(); ++i)
+        {
+            size_t j = 0;
+            for (; j < options.size(); ++j)
+                if (options[j] == it->second->options[i])
+                    break;
+
+            if (j == options.size())
+            {
+                same_options = false;
+                break;
+            }
+        }
+
         // nothing to do
-        if (!force && !create_policy &&
-            policy == working_files[full_file]->policy && display == working_files[full_file]->display
-            && verbosity == working_files[full_file]->verbosity)
+        if (!force && !create_policy && same_options &&
+            policy == it->second->policy && display == it->second->display
+            && verbosity == it->second->verbosity)
         {
             working_files_mutex.unlock();
             return 0;
@@ -196,6 +212,8 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
     fr->display = display;
     fr->verbosity = verbosity;
     fr->create_policy = create_policy;
+    for (size_t i = 0; i < options.size(); ++i)
+        fr->options.push_back(options[i]);
 
     working_files_mutex.lock();
 
@@ -221,7 +239,7 @@ int WorkerFiles::add_file_to_list(const std::string& file, const std::string& pa
 
     int ret;
     std::vector<long> files_id;
-    if ((ret = mainwindow->analyze(vec, fixer, force, files_id, err)) < 0)
+    if ((ret = mainwindow->analyze(vec, fixer, force, options, files_id, err)) < 0)
     {
         mainwindow->set_str_msg_to_status_bar(err);
         return -1;
@@ -288,24 +306,41 @@ int WorkerFiles::add_file_to_list(long id, const std::string& full_file, const s
 
 //---------------------------------------------------------------------------
 int WorkerFiles::add_attachment_to_list(const std::string& file, int policy, int display,
-                                        int verbosity, std::string& err)
+                                        int verbosity, const std::vector<std::string>& options, std::string& err)
 {
     bool exists = false;
     FileRegistered *fr = NULL;
+
     working_files_mutex.lock();
-    if (working_files.find(file) != working_files.end() && working_files[file])
+    std::map<std::string, FileRegistered*>::iterator it = working_files.find(file);
+    if (it != working_files.end() && it->second)
     {
         exists = true;
+        bool same_options = true;
+        for (size_t i = 0; i < it->second->options.size(); ++i)
+        {
+            size_t j = 0;
+            for (; j < options.size(); ++j)
+                if (options[j] == it->second->options[i])
+                    break;
+
+            if (j == options.size())
+            {
+                same_options = false;
+                break;
+            }
+        }
+
         // nothing to do
-        if (policy == working_files[file]->policy && display == working_files[file]->display
-            && verbosity == working_files[file]->verbosity)
+        if (same_options && policy == it->second->policy &&
+            display == it->second->display && verbosity == it->second->verbosity)
         {
             working_files_mutex.unlock();
             return 0;
         }
         else
             fr = new FileRegistered;
-        fr->analyzed = working_files[file]->analyzed;
+        fr->analyzed = it->second->analyzed;
     }
     else
         fr = new FileRegistered;
@@ -326,6 +361,8 @@ int WorkerFiles::add_attachment_to_list(const std::string& file, int policy, int
     fr->display = display;
     fr->verbosity = verbosity;
     fr->create_policy = false;
+    for (size_t i = 0; i < options.size(); ++i)
+        fr->options.push_back(options[i]);
 
     working_files_mutex.lock();
 
@@ -351,7 +388,7 @@ int WorkerFiles::add_attachment_to_list(const std::string& file, int policy, int
 
     int ret;
     std::vector<long> files_id;
-    if ((ret = mainwindow->analyze(vec, false, false, files_id, err)) < 0)
+    if ((ret = mainwindow->analyze(vec, false, false, options, files_id, err)) < 0)
     {
         mainwindow->set_str_msg_to_status_bar(err);
         return -1;
@@ -373,9 +410,10 @@ int WorkerFiles::add_attachment_to_list(const std::string& file, int policy, int
 }
 
 //---------------------------------------------------------------------------
-void WorkerFiles::update_policy_of_file_registered_from_file(long file_id, int policy)
+int WorkerFiles::update_policy_of_file_registered_from_file(long file_id, long policy, std::string& error)
 {
     std::string file;
+    FileRegistered* fr = NULL;
     working_files_mutex.lock();
     std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
     for (; it != working_files.end(); ++it)
@@ -384,24 +422,32 @@ void WorkerFiles::update_policy_of_file_registered_from_file(long file_id, int p
             continue;
 
         file = it->first;
+        fr = it->second;
         break;
     }
 
-    if (!file.size())
+    if (!fr)
     {
         // file is not existing
+        error = "File not reachable";
         working_files_mutex.unlock();
-        return;
+        return -1;
     }
 
-    working_files[file]->policy = policy;
+    fr->policy = policy;
 
     bool policy_valid = false;
-    if (working_files[file]->analyzed && policy >= 0)
+    if (!fr->analyzed)
     {
+        error = "File not analyzed";
         working_files_mutex.unlock();
+        return -1;
+    }
 
-        std::string err;
+    working_files_mutex.unlock();
+
+    if (policy >= 0)
+    {
         std::vector<size_t> policies_ids;
         std::vector<std::string> policies_contents;
         std::vector<MediaConchLib::Checker_ValidateRes*> res;
@@ -409,24 +455,27 @@ void WorkerFiles::update_policy_of_file_registered_from_file(long file_id, int p
         policies_ids.push_back(policy);
 
         if (mainwindow->validate(MediaConchLib::report_Max, file,
-                                 policies_ids, policies_contents, options, res, err) == 0 && res.size() == 1)
+                                 policies_ids, policies_contents, options, res, error) < 0)
+            return -1;
+
+        if (res.size() == 1)
         {
             policy_valid = res[0]->valid;
             for (size_t j = 0; j < res.size() ; ++j)
                 delete res[j];
             res.clear();
         }
-
-        working_files_mutex.lock();
     }
 
+    working_files_mutex.lock();
     working_files[file]->policy_valid = policy_valid;
-    FileRegistered fr = *working_files[file];
+    FileRegistered tmp = *working_files[file];
     working_files_mutex.unlock();
 
     to_update_files_mutex.lock();
-    to_update_files[file] = new FileRegistered(fr);
+    to_update_files[file] = new FileRegistered(tmp);
     to_update_files_mutex.unlock();
+    return 0;
 }
 
 //---------------------------------------------------------------------------
@@ -525,13 +574,18 @@ void WorkerFiles::update_update_files_registered()
 void WorkerFiles::update_delete_files_registered()
 {
     std::vector<FileRegistered*> vec;
+    std::vector<long> ids;
 
     to_delete_files_mutex.lock();
     if (to_delete_files.size())
     {
         std::map<std::string, FileRegistered*>::iterator it = to_delete_files.begin();
         for (; it != to_delete_files.end(); ++it)
+        {
             vec.push_back(it->second);
+            if (it->second)
+                ids.push_back(it->second->file_id);
+        }
         to_delete_files.clear();
     }
     to_delete_files_mutex.unlock();
@@ -540,6 +594,7 @@ void WorkerFiles::update_delete_files_registered()
         return;
 
     remove_registered_files_from_db(vec);
+    mainwindow->checker_stop(ids);
     for (size_t i = 0; i < vec.size(); ++i)
         delete vec[i];
     vec.clear();
@@ -851,7 +906,7 @@ void WorkerFiles::fill_registered_files_from_db()
 
         int ret;
         std::vector<long> files_id;
-        if ((ret = mainwindow->analyze(tmp, false, false, files_id, err2)) < 0)
+        if ((ret = mainwindow->analyze(tmp, false, false, fr->options, files_id, err2)) < 0)
             mainwindow->set_str_msg_to_status_bar(err2);
         else if (!files_id.size())
             mainwindow->set_str_msg_to_status_bar("Internal error: Analyze result is not correct.");
